summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorWu-cheng Li <wuchengli@google.com>2010-02-20 17:47:04 +0800
committerWu-cheng Li <wuchengli@google.com>2010-02-26 14:04:43 +0800
commit24b326a8978bf78e3e560723dde221792784325b (patch)
treea675e74ca0e7f430cf4f1386032154fc8895fd96 /include
parent4d98579f43026a8213b0570e7836648902741005 (diff)
downloadframeworks_base-24b326a8978bf78e3e560723dde221792784325b.zip
frameworks_base-24b326a8978bf78e3e560723dde221792784325b.tar.gz
frameworks_base-24b326a8978bf78e3e560723dde221792784325b.tar.bz2
Unhide exposure compensation API.
bug:2375993
Diffstat (limited to 'include')
-rw-r--r--include/camera/CameraParameters.h21
1 files changed, 14 insertions, 7 deletions
diff --git a/include/camera/CameraParameters.h b/include/camera/CameraParameters.h
index e328f33..9df2695 100644
--- a/include/camera/CameraParameters.h
+++ b/include/camera/CameraParameters.h
@@ -187,16 +187,23 @@ public:
// Vertical angle of view in degrees.
// Example value: "42.5". Read only.
static const char KEY_VERTICAL_VIEW_ANGLE[];
- // Exposure compensation. The value is multiplied by 100. -100 means -1 EV.
- // 130 means +1.3 EV.
- // Example value: "0" or "133". Read/write.
+ // Exposure compensation index. 0 means exposure is not adjusted.
+ // Example value: "0" or "5". Read/write.
static const char KEY_EXPOSURE_COMPENSATION[];
- // Supported exposure compensation.
- // Example value: "-100,-66,-33,0,33,66,100". Read only.
- static const char KEY_SUPPORTED_EXPOSURE_COMPENSATION[];
+ // The maximum exposure compensation index (>=0).
+ // Example value: "6". Read only.
+ static const char KEY_MAX_EXPOSURE_COMPENSATION[];
+ // The minimum exposure compensation index (<=0).
+ // Example value: "-6". Read only.
+ static const char KEY_MIN_EXPOSURE_COMPENSATION[];
+ // The exposure compensation step. Exposure compensation index multiply by
+ // step eqals to EV. Ex: if exposure compensation index is 6 and step is
+ // 0.3333, EV is -2.
+ // Example value: "0.333333333" or "0.5". Read only.
+ static const char KEY_EXPOSURE_COMPENSATION_STEP[];
- // Values for white balance settings.
+ // Values for white balance settings.
static const char WHITE_BALANCE_AUTO[];
static const char WHITE_BALANCE_INCANDESCENT[];
static const char WHITE_BALANCE_FLUORESCENT[];